Learn R Programming

ntfy (version 0.1.0)

ntfy-package: ntfy: Lightweight Wrapper to the 'ntfy.sh' Service

Description

logo

The 'ntfy' (pronounce: notify) service is a simple HTTP-based pub-sub notification service. It allows you to send notifications to your phone or desktop via scripts from any computer, entirely without signup, cost or setup. It's also open source if you want to run your own. Visit https://ntfy.sh for more details.

Arguments

Author

Maintainer: Jonathan Carroll rpkg@jcarroll.com.au (ORCID)

Other contributors:

See Also