show_emoji: Show an emoji symbol, or find one by name
Description
Show an emoji symbol, or find one by name
Usage
show_emoji(name = NULL, search = FALSE)
Value
nothing, just prints the emoji if one or more are found
Arguments
name
name of emoji to either print or find
search
search the tags column for this name?
Details
Emoji are loaded with data("emoji") and the aliases column
contains the names compatible with ntfy. Alternative names are
included in the tags column and these will be searched if the
name is not found in aliases.